@@ -131,13 +131,11 @@ typedef struct _GnomePrintConfig GnomePrintConfig;
 #include <glib-object.h>
 #include <libgnomeprint/gnome-print-unit.h>
 
-/*
- * Get default print config objects
- */
+#define GNOME_TYPE_PRINT_CONFIG         (gnome_print_config_get_type ())
+#define GNOME_PRINT_CONFIG(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GNOME_TYPE_PRINT_CONFIG, GnomePrintConfig))
+#define GNOME_IS_PRINT_CONFIG(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNOME_TYPE_PRINT_CONFIG))
 
-#define GNOME_TYPE_PRINT_CONFIG (gnome_print_config_get_type ())
-
-GType gnome_print_config_get_type (void);
+GType             gnome_print_config_get_type (void);
 
 GnomePrintConfig *gnome_print_config_default (void);
 
@@ -169,6 +167,11 @@ gboolean gnome_print_config_set_int     (GnomePrintConfig *config, const guchar
 gboolean gnome_print_config_set_double  (GnomePrintConfig *config, const guchar *key, gdouble val);
 gboolean gnome_print_config_set_length  (GnomePrintConfig *config, const guchar *key, gdouble val, const GnomePrintUnit *unit);
 
+/*
+ * Convenience
+ */
+gboolean  gnome_print_config_get_page_size (GnomePrintConfig *config, gdouble *width, gdouble *height);
+
 /*
  * Debugging
  */
